%global appname Quotient
%global libname lib%{appname}
%global _description %{expand:
The Quotient project aims to produce a Qt-based SDK to develop applications
for Matrix. libQuotient is a library that enables client applications. It is
the backbone of Quaternion, Spectral and other projects. Versions 0.5.x and
older use the previous name - libQMatrixClient.}

Name: libquotient
Version: 0.8.1.2
Release:    1%{?dist}

License: BSD-3-Clause AND LGPL-2.1-or-later
URL: https://github.com/quotient-im/%{libname}
Summary: Qt library to write cross-platform clients for Matrix
Source0: %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires: cmake(Olm)
BuildRequires: cmake(Qt5Concurrent)
BuildRequires: cmake(Qt5Core)
BuildRequires: cmake(Qt5Keychain)
BuildRequires: cmake(Qt5LinguistTools)
BuildRequires: cmake(Qt5Multimedia)
BuildRequires: cmake(Qt5Network)
BuildRequires: cmake(Qt5Sql)
BuildRequires: cmake(Qt5Widgets)
BuildRequires: cmake(Qt6Core)
BuildRequires: cmake(Qt6Keychain)
BuildRequires: cmake(Qt6LinguistTools)
BuildRequires: cmake(Qt6Multimedia)
BuildRequires: cmake(Qt6Network)
BuildRequires: cmake(Qt6Sql)
BuildRequires: cmake(Qt6Widgets)
BuildRequires: cmake(QtOlm)
BuildRequires: pkgconfig(openssl)

BuildRequires: cmake
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: ninja-build

%description %_description

%package qt5
Summary: Files for qt5
Provides: %{name} = %{version}-%{release}
%description qt5 %_description

%package qt5-devel
Summary: Development files for %{name} for qt5
Provides: %{name}-devel = %{version}-%{release}
Requires: %{name}-qt5 = %{version}-%{release}
Requires: cmake(Olm)
Requires: cmake(Qt5Sql)
Requires: cmake(QtOlm)
Requires: pkgconfig(openssl)
%description qt5-devel %_description

%package qt6
Summary: Files for qt6
%description qt6 %_description

%package qt6-devel
Summary: Development files for %{name} for qt6
Requires: %{name}-qt6 = %{version}-%{release}
Requires: cmake(Olm)
Requires: cmake(Qt6Sql)
Requires: cmake(QtOlm)
Requires: pkgconfig(openssl)
%description qt6-devel %_description

%prep
%autosetup -n %{libname}-%{version}
rm -rf 3rdparty

%build
mkdir %{name}_qt5
pushd %{name}_qt5
%cmake -G Ninja \
    -S'..' \
    -DCMAKE_BUILD_TYPE=Release \
    -DQuotient_ENABLE_E2EE:BOOL=ON \
    -DQuotient_INSTALL_TESTS:BOOL=OFF \
    -DQuotient_INSTALL_EXAMPLE:BOOL=OFF
%cmake_build
popd
mkdir %{name}_qt6
pushd %{name}_qt6
%cmake -G Ninja \
    -S'..' \
    -DCMAKE_BUILD_TYPE=Release \
    -DQuotient_ENABLE_E2EE:BOOL=ON \
    -DQuotient_INSTALL_TESTS:BOOL=OFF \
    -DQuotient_INSTALL_EXAMPLE:BOOL=OFF \
    -DBUILD_WITH_QT6=ON
%cmake_build
popd


%check
pushd %{name}_qt5
%ctest --exclude-regex 'testolmaccount|testkeyverification'
popd
pushd %{name}_qt6
%ctest --exclude-regex 'testolmaccount|testkeyverification'
popd

%install
pushd %{name}_qt5
%cmake_install
popd
pushd %{name}_qt6
%cmake_install
popd
rm -rf %{buildroot}%{_datadir}/ndk-modules

%files qt5
%license COPYING
%doc README.md CONTRIBUTING.md SECURITY.md
%{_libdir}/%{libname}.so.0*

%files qt5-devel
%{_includedir}/%{appname}/
%{_libdir}/cmake/%{appname}/
%{_libdir}/pkgconfig/%{appname}.pc
%{_libdir}/%{libname}.so

%files qt6
%license COPYING
%doc README.md CONTRIBUTING.md SECURITY.md
%{_libdir}/%{libname}Qt6.so.0*

%files qt6-devel
%{_libdir}/cmake/%{appname}Qt6/
%{_libdir}/%{libname}Qt6.so
%{_libdir}/pkgconfig/%{appname}Qt6.pc

%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.1.2-1
- initial build
